.. title:: Home

.. meta::
   :description: A modern, easy to use, Python ≥3.8 library for interacting with OBDII devices.
   :twitter:description: A modern, easy to use, Python ≥3.8 library for interacting with OBDII devices.

.. include:: ../../.github/README.rst
   :parser: rst

.. toctree::
   :hidden:
   :caption: Contents:

   emulator
   api